@@ -14,7 +14,7 @@ Usage::
     client: KendraClient = boto3.client("kendra")
     session_client: KendraClient = session.client("kendra")
 """
-from mypy_boto3_kendra.client import KendraClient as Client, KendraClient
+from mypy_boto3_kendra.client import KendraClient, KendraClient as Client
 
 
 __all__ = ("Client", "KendraClient")
