@@ -13,7 +13,7 @@ Usage::
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
-from typing import Any, Dict, List, TYPE_CHECKING
+from typing import Any, Dict, List, TYPE_CHECKING, Type
 from botocore.exceptions import ClientError as Boto3ClientError
 from mypy_boto3_kendra.type_defs import (
     AttributeFilterTypeDef,
@@ -52,22 +52,22 @@ __all__ = ("KendraClient",)
 
 
 class Exceptions:
-    AccessDeniedException: Boto3ClientError
-    ClientError: Boto3ClientError
-    ConflictException: Boto3ClientError
-    InternalServerException: Boto3ClientError
-    ResourceAlreadyExistException: Boto3ClientError
-    ResourceInUseException: Boto3ClientError
-    ResourceNotFoundException: Boto3ClientError
-    ResourceUnavailableException: Boto3ClientError
-    ServiceQuotaExceededException: Boto3ClientError
-    ThrottlingException: Boto3ClientError
-    ValidationException: Boto3ClientError
+    AccessDeniedException: Type[Boto3ClientError]
+    ClientError: Type[Boto3ClientError]
+    ConflictException: Type[Boto3ClientError]
+    InternalServerException: Type[Boto3ClientError]
+    ResourceAlreadyExistException: Type[Boto3ClientError]
+    ResourceInUseException: Type[Boto3ClientError]
+    ResourceNotFoundException: Type[Boto3ClientError]
+    ResourceUnavailableException: Type[Boto3ClientError]
+    ServiceQuotaExceededException: Type[Boto3ClientError]
+    ThrottlingException: Type[Boto3ClientError]
+    ValidationException: Type[Boto3ClientError]
 
 
 class KendraClient:
     """
-    [Kendra.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.9/reference/services/kendra.html#Kendra.Client)
+    [Kendra.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.42/reference/services/kendra.html#Kendra.Client)
     """
 
     exceptions: Exceptions
@@ -76,19 +76,19 @@ class KendraClient:
         self, IndexId: str, DocumentIdList: List[str]
     ) -> BatchDeleteDocumentResponseTypeDef:
         """
-        [Client.batch_delete_document documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.9/reference/services/kendra.html#Kendra.Client.batch_delete_document)
+        [Client.batch_delete_document documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.42/reference/services/kendra.html#Kendra.Client.batch_delete_document)
         """
 
     def batch_put_document(
         self, IndexId: str, Documents: List[DocumentTypeDef], RoleArn: str = None
     ) -> BatchPutDocumentResponseTypeDef:
         """
-        [Client.batch_put_document documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.9/reference/services/kendra.html#Kendra.Client.batch_put_document)
+        [Client.batch_put_document documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.42/reference/services/kendra.html#Kendra.Client.batch_put_document)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.9/reference/services/kendra.html#Kendra.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.42/reference/services/kendra.html#Kendra.Client.can_paginate)
         """
 
     def create_data_source(
@@ -102,14 +102,14 @@ class KendraClient:
         Schedule: str = None,
     ) -> CreateDataSourceResponseTypeDef:
         """
-        [Client.create_data_source documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.9/reference/services/kendra.html#Kendra.Client.create_data_source)
+        [Client.create_data_source documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.42/reference/services/kendra.html#Kendra.Client.create_data_source)
         """
 
     def create_faq(
         self, IndexId: str, Name: str, S3Path: S3PathTypeDef, RoleArn: str, Description: str = None
     ) -> CreateFaqResponseTypeDef:
         """
-        [Client.create_faq documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.9/reference/services/kendra.html#Kendra.Client.create_faq)
+        [Client.create_faq documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.42/reference/services/kendra.html#Kendra.Client.create_faq)
         """
 
     def create_index(
@@ -118,34 +118,35 @@ class KendraClient:
         RoleArn: str,
         ServerSideEncryptionConfiguration: ServerSideEncryptionConfigurationTypeDef = None,
         Description: str = None,
+        ClientToken: str = None,
     ) -> CreateIndexResponseTypeDef:
         """
-        [Client.create_index documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.9/reference/services/kendra.html#Kendra.Client.create_index)
+        [Client.create_index documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.42/reference/services/kendra.html#Kendra.Client.create_index)
         """
 
     def delete_faq(self, Id: str, IndexId: str) -> None:
         """
-        [Client.delete_faq documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.9/reference/services/kendra.html#Kendra.Client.delete_faq)
+        [Client.delete_faq documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.42/reference/services/kendra.html#Kendra.Client.delete_faq)
         """
 
     def delete_index(self, Id: str) -> None:
         """
-        [Client.delete_index documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.9/reference/services/kendra.html#Kendra.Client.delete_index)
+        [Client.delete_index documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.42/reference/services/kendra.html#Kendra.Client.delete_index)
         """
 
     def describe_data_source(self, Id: str, IndexId: str) -> DescribeDataSourceResponseTypeDef:
         """
-        [Client.describe_data_source documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.9/reference/services/kendra.html#Kendra.Client.describe_data_source)
+        [Client.describe_data_source documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.42/reference/services/kendra.html#Kendra.Client.describe_data_source)
         """
 
     def describe_faq(self, Id: str, IndexId: str) -> DescribeFaqResponseTypeDef:
         """
-        [Client.describe_faq documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.9/reference/services/kendra.html#Kendra.Client.describe_faq)
+        [Client.describe_faq documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.42/reference/services/kendra.html#Kendra.Client.describe_faq)
         """
 
     def describe_index(self, Id: str) -> DescribeIndexResponseTypeDef:
         """
-        [Client.describe_index documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.9/reference/services/kendra.html#Kendra.Client.describe_index)
+        [Client.describe_index documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.42/reference/services/kendra.html#Kendra.Client.describe_index)
         """
 
     def generate_presigned_url(
@@ -156,7 +157,7 @@ class KendraClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.9/reference/services/kendra.html#Kendra.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.42/reference/services/kendra.html#Kendra.Client.generate_presigned_url)
         """
 
     def list_data_source_sync_jobs(
@@ -171,28 +172,28 @@ class KendraClient:
         ] = None,
     ) -> ListDataSourceSyncJobsResponseTypeDef:
         """
-        [Client.list_data_source_sync_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.9/reference/services/kendra.html#Kendra.Client.list_data_source_sync_jobs)
+        [Client.list_data_source_sync_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.42/reference/services/kendra.html#Kendra.Client.list_data_source_sync_jobs)
         """
 
     def list_data_sources(
         self, IndexId: str, NextToken: str = None, MaxResults: int = None
     ) -> ListDataSourcesResponseTypeDef:
         """
-        [Client.list_data_sources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.9/reference/services/kendra.html#Kendra.Client.list_data_sources)
+        [Client.list_data_sources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.42/reference/services/kendra.html#Kendra.Client.list_data_sources)
         """
 
     def list_faqs(
         self, IndexId: str, NextToken: str = None, MaxResults: int = None
     ) -> ListFaqsResponseTypeDef:
         """
-        [Client.list_faqs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.9/reference/services/kendra.html#Kendra.Client.list_faqs)
+        [Client.list_faqs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.42/reference/services/kendra.html#Kendra.Client.list_faqs)
         """
 
     def list_indices(
         self, NextToken: str = None, MaxResults: int = None
     ) -> ListIndicesResponseTypeDef:
         """
-        [Client.list_indices documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.9/reference/services/kendra.html#Kendra.Client.list_indices)
+        [Client.list_indices documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.42/reference/services/kendra.html#Kendra.Client.list_indices)
         """
 
     def query(
@@ -207,19 +208,19 @@ class KendraClient:
         PageSize: int = None,
     ) -> QueryResultTypeDef:
         """
-        [Client.query documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.9/reference/services/kendra.html#Kendra.Client.query)
+        [Client.query documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.42/reference/services/kendra.html#Kendra.Client.query)
         """
 
     def start_data_source_sync_job(
         self, Id: str, IndexId: str
     ) -> StartDataSourceSyncJobResponseTypeDef:
         """
-        [Client.start_data_source_sync_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.9/reference/services/kendra.html#Kendra.Client.start_data_source_sync_job)
+        [Client.start_data_source_sync_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.42/reference/services/kendra.html#Kendra.Client.start_data_source_sync_job)
         """
 
     def stop_data_source_sync_job(self, Id: str, IndexId: str) -> None:
         """
-        [Client.stop_data_source_sync_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.9/reference/services/kendra.html#Kendra.Client.stop_data_source_sync_job)
+        [Client.stop_data_source_sync_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.42/reference/services/kendra.html#Kendra.Client.stop_data_source_sync_job)
         """
 
     def submit_feedback(
@@ -230,7 +231,7 @@ class KendraClient:
         RelevanceFeedbackItems: List[RelevanceFeedbackTypeDef] = None,
     ) -> None:
         """
-        [Client.submit_feedback documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.9/reference/services/kendra.html#Kendra.Client.submit_feedback)
+        [Client.submit_feedback documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.42/reference/services/kendra.html#Kendra.Client.submit_feedback)
         """
 
     def update_data_source(
@@ -244,7 +245,7 @@ class KendraClient:
         RoleArn: str = None,
     ) -> None:
         """
-        [Client.update_data_source documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.9/reference/services/kendra.html#Kendra.Client.update_data_source)
+        [Client.update_data_source documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.42/reference/services/kendra.html#Kendra.Client.update_data_source)
         """
 
     def update_index(
@@ -256,5 +257,5 @@ class KendraClient:
         DocumentMetadataConfigurationUpdates: List[DocumentMetadataConfigurationTypeDef] = None,
     ) -> None:
         """
-        [Client.update_index documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.9/reference/services/kendra.html#Kendra.Client.update_index)
+        [Client.update_index documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.42/reference/services/kendra.html#Kendra.Client.update_index)
         """
