@@ -254,6 +254,9 @@ _OptionalSharePointConfigurationTypeDef = TypedDict(
     "_OptionalSharePointConfigurationTypeDef",
     {
         "CrawlAttachments": bool,
+        "UseChangeLog": bool,
+        "InclusionPatterns": List[str],
+        "ExclusionPatterns": List[str],
         "VpcConfiguration": DataSourceVpcConfigurationTypeDef,
         "FieldMappings": List[DataSourceToIndexFieldMappingTypeDef],
         "DocumentTitleFieldName": str,
